## 0.3 (2015-06-30
- Publish aloisius to PyPI

## 0.2.1 (2015-06-29)
- Increase parallelism by using FutureOutputs

## 0.2 (2015-06-28)
- Add support for parallel stack operations

## 0.1 (2015-06-27)
- First release
